@@ -356,7 +356,7 @@ class SSHContext(BaseContext):
         # for ii in job_dirs :
         for task in submission.belonging_tasks :
             for jj in task.backward_files:
-                file_name = os.path.join(task.task_work_path, jj)                
+                file_name = pathlib.PurePath(os.path.join(task.task_work_path, jj)).as_posix()
                 if check_exists:
                     if self.check_file_exists(file_name):
                         file_list.append(file_name)
